searchData={"items":[{"type":"module","title":"EasyRpc","doc":"EasyRpc is a library help Elixir developer can work easily in Elixir cluster.\nPlease go to README for more information.","ref":"EasyRpc.html"},{"type":"module","title":"EasyRpc.NodeUtils","doc":"NodeUtils is a helper module to help get target node in Elixir cluster.\nSupport strategies: random, round-robin, hash.\nFor case round-robin, the module will using process dictionary to store the current index.","ref":"EasyRpc.NodeUtils.html"},{"type":"function","title":"EasyRpc.NodeUtils.select_node/3","doc":"Helper function to calculate target node by random, round-robin, or hash.","ref":"EasyRpc.NodeUtils.html#select_node/3"},{"type":"module","title":"EasyRpc.RpcWrapper","doc":"This module provides a wrapper for RPC (Remote Procedure Call) in Elixir.\nIt helps to call remote functions as local functions.\nThe library uses macro to create a local function (declare by config).\n\nCurrently, the you can wrapping multiple remote functions in a module.\nYou can use same name or different name for remote functions.\nYou also can have multiple wrappers for multiple remote modules.\n\n# Guide","ref":"EasyRpc.RpcWrapper.html"},{"type":"module","title":"Add config for RpcWrapper - EasyRpc.RpcWrapper","doc":"Put config to config.exs file in your project.\nFor multi wrapper, you need to separate configs for each wrapper.\n\nExample:\n\n```Elixir\nconfig :app_name, :wrapper_name,\n  nodes: [:\"test1@test.local\", :\"test2@test.local\"],\n  # or nodes: {MyModule, :get_nodes, []}\n  error_handling: true, # enable error handling, global setting for all functions.\n  select_mode: :random, # select node mode, global setting for all functions.\n  module: TargetApp.RemoteModule,\n  functions: [\n    # {function_name, arity, options \\ []}\n    {:get_data, 1},\n    {:put_data, 1, error_handling: false},\n    {:clear, 2, [new_name: :clear_data]},\n    {:put_data, 1, [new_name: :put_with_retry, retry: 3]}\n  ]\n```\n\nExplain config:\n\n`:nodes` List of nodes, or {module, function, args} on local node.\n`:module` Module of remote functions on remote node.\n`:error_handling` Enable error handling (catch all) or not.\n`:select_mode` Select node mode, support for random, round_robin, hash.\n`:functions` List of functions, each function is a tuple {function_name, arity} or {function_name, new_name, arity, opts}.\n`:options` Keyword of options, including new_name, retry, error_handling. Ex: [new_name: :clear_data, retry: 0, error_handling: true].\n  If retry is set, the function will retry n times when error occurs and error_handling will be applied.\n  If error_handling is set, the function will catch all exceptions and return {:error, reason}.","ref":"EasyRpc.RpcWrapper.html#module-add-config-for-rpcwrapper"},{"type":"module","title":"RpcWrapper - EasyRpc.RpcWrapper","doc":"Usage:\nby using RpcWrapper in your module, you can call remote functions as local functions.\n\nExample:\n\n```Elixir\ndefmodule DataHelper do\nuse EasyRpc.RpcWrapper,\n  otp_app: :app_name,\n  config_name: :wrapper_name\n\ndef process_remote() do\n  case get_data(\"key\") do\n    {:ok, data} ->\n      # do something with data\n    {:error, reason} ->\n      # handle error\n  end\nend\n```\n\nExplain:\n`:otp_app`, name of application will add config\n`:config_name`, name of config in application config.","ref":"EasyRpc.RpcWrapper.html#module-rpcwrapper"},{"type":"function","title":"EasyRpc.RpcWrapper.get_config!/2","doc":"Get config from application env.","ref":"EasyRpc.RpcWrapper.html#get_config!/2"},{"type":"function","title":"EasyRpc.RpcWrapper.get_config!/3","doc":"Get config from application env.","ref":"EasyRpc.RpcWrapper.html#get_config!/3"},{"type":"function","title":"EasyRpc.RpcWrapper.rpc_call/3","doc":"rpc wrapper, support for define macro.","ref":"EasyRpc.RpcWrapper.html#rpc_call/3"},{"type":"function","title":"EasyRpc.RpcWrapper.rpc_call_error_handling/4","doc":"rpc wrapper, support for define macro.","ref":"EasyRpc.RpcWrapper.html#rpc_call_error_handling/4"},{"type":"function","title":"EasyRpc.RpcWrapper.valid_strategy!/1","doc":"Validate select strategy.","ref":"EasyRpc.RpcWrapper.html#valid_strategy!/1"},{"type":"exception","title":"EasyRpc.RpcWrapper.RpcWrapperError","doc":"","ref":"EasyRpc.RpcWrapper.RpcWrapperError.html"},{"type":"function","title":"EasyRpc.RpcWrapper.RpcWrapperError.raise_error/1","doc":"","ref":"EasyRpc.RpcWrapper.RpcWrapperError.html#raise_error/1"},{"type":"extras","title":"Readme","doc":"[![Docs](https://img.shields.io/badge/api-docs-green.svg?style=flat)](https://hexdocs.pm/easy_rpc)\n[![Hex.pm](https://img.shields.io/hexpm/v/easy_rpc.svg?style=flat&color=blue)](https://hex.pm/packages/easy_rpc)\n\n# EasyRpc\n\nThis library help developer easy to wrap a remote procedure call (rpc, library uses Erlang `:erpc` module).","ref":"readme.html"},{"type":"extras","title":"Installation - Readme","doc":"Adding `easy_rpc` library to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:easy_rpc, \"~> 0.1.3\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Readme","doc":"Follow steps","ref":"readme.html#usage"},{"type":"extras","title":"Add config to config.exs - Readme","doc":"Put config to config.exs file, and use it in your module by using RpcWrapper.\nUser need separate config for each wrapper, and put it in config.exs\n\n```Elixir\nconfig :app_name, :wrapper_name,\n  nodes: [:\"test1@test.local\"],\n  error_handling: true,\n  select_mode: :random,\n  module: TargetApp.Interface.Api,\n  functions: [\n    # {function_name, arity, options}\n    {:get_data, 1},\n    {:put_data, 1, error_handling: false},\n    {:clear, 2, new_name: :clear_data, retry: 3},\n  ]\n```","ref":"readme.html#add-config-to-config-exs"},{"type":"extras","title":"Add to local module - Readme","doc":"by using `use EasyRpc.RpcWrapper` in your module, you can call remote functions as local functions.\n\n```Elixir\ndefmodule DataHelper do\n  use EasyRpc.RpcWrapper,\n    otp_app: :app_name,\n    config_name: :account_wrapper\n\n  def process_remote() do\n    # call rpc like a local function.\n    case get_data(\"key\") do\n      {:ok, data} ->\n        # do something with data\n\n      {:error, reason} ->\n        # handle error\n    end\n  end\nend\n\n# Or call from other module\n{:ok, result} = DataHelper.get_data(\"my_key\")\n```\n\nFor more details please go to module's docs.","ref":"readme.html#add-to-local-module"},{"type":"extras","title":"Example - Readme","doc":"You can go to example folder to see how config & how to wrap a remote module.\n\nGo to [Github](https://github.com/ohhi-vn/easy_rpc/tree/main/example) and follow the README in each sub folder.","ref":"readme.html#example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}